@@ -330,7 +330,7 @@ stop("\n Leaf apex must be on the top right corner of leaf base!
             cex=1.5, xaxs="i", yaxs="i",
             xlim=xlim0, ylim=ylim0, las=1,
             xlab=expression(paste("ln ", 
-            italic("\u03B4"), {""}^{-"1"}, sep="")), 
+            delta, {""}^{-"1"}, sep="")), 
             ylab=expression(paste("ln ", italic("N"), sep="")) )
       title(main=main, cex.main=1.5, col.main=4, font.main=1)
       abline( resu, col=2 )   
