@@ -7,12 +7,17 @@ sigmoid <- function(expr, P, x, simpver = 1, subdivisions = 100L,
      expr(P, x=x, simpver=simpver)
    }
 
-   if(is.null(simpver)){
+   if(is.null(simpver) & !identical(expr, MPerformanceE)){
      Lower <- P[3]
      Upper <- P[4]
    }
 
-   if(!is.null(simpver)){
+   if(is.null(simpver) & identical(expr, MPerformanceE)){
+     Lower <- P[4]
+     Upper <- P[5]
+   }
+
+   if(!is.null(simpver) & !identical(expr, MPerformanceE)){
 
     if( !(simpver %in% seq(1, 3, by=1)) )
     stop("'simpver' should be chosen in versions 1 to 3!")  
@@ -27,6 +32,25 @@ sigmoid <- function(expr, P, x, simpver = 1, subdivisions = 100L,
     }
    }
 
+   if(!is.null(simpver) & identical(expr, MPerformanceE)){
+
+    if( !(simpver %in% seq(1, 5, by=1)) )
+    stop("'simpver' should be chosen in versions 1 to 5!")  
+  
+    if(simpver==1 | simpver==3){
+      Lower <- 0
+      Upper <- P[4]
+    }
+    if(simpver==2){
+      Lower <- P[4]
+      Upper <- P[5]
+    }
+    if(simpver==4 | simpver==5){
+      Lower <- 0
+      Upper <- sqrt(2)
+    }
+   }
+
    yval <- c()
    for(i in 1:length(x)){
      if(x[i] < Lower) x[i] <- Lower
